;;; oni-package.el --- Package manager configuration  -*- lexical-binding: t; -*-

;; Copyright (C) 2019  Tom Willemse

;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 20190218235251

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:

;; Configuration file for ELPA. This configuration adds the following
;; archives:

;;   - melpa: For all the latest packages.
;;   - org: For the latest version of org-mode.
;;   - oni: For my personal package configuration.

;; This configuration also sets up the proper variables for uploading
;; packages to my personal repository.

;;; Code:

(require 'package)
(require 'package-x)

;;;###autoload
(add-to-list 'package-archives
             '("melpa" . "https://melpa.org/packages/"))

;;;###autoload
(add-to-list 'package-archives
             '("org" . "http://orgmode.org/elpa/"))

;;;###autoload
(add-to-list 'package-archives
             `("oni" . "https://ryuslash.org/elpa/"))

;;; Specify where to upload packages to. Used by
;;; ‘package-upload-buffer’ and ‘package-upload-file’.
(setq package-archive-upload-base
      "/ssh:ryuslash.org:usr/share/emacs/elpa/")

;;; Temporary fix for `package-maint-add-news-item', until I get my
;;; Copyright assignment back in order.
(defun package-maint-add-news-item (title description archive-url)
  "Add a news item to the webpages associated with the package archive.
TITLE is the title of the news item.
DESCRIPTION is the text of the news item."
  (interactive
   (list
    (read-string "Title: ")
    (read-string "Text: ")
    (let ((archive-name
           (completing-read "Archive: " (mapcar 'car package-archives))))
      (or (alist-get archive-name package-archives nil nil #'string-equal)
          archive-name))))
  (package--update-file "elpa.rss"
			            "<description>"
			            (package--make-rss-entry title description archive-url))
  (package--update-file "news.html"
			            "New entries go here"
			            (package--make-html-entry title description)))

(add-hook 'package-menu-mode-hook 'hl-line-mode)

;;;###autoload (with-eval-after-load 'package (require 'oni-package))
;;;###autoload (with-eval-after-load 'package-x (require 'oni-package))

(provide 'oni-package)
;;; oni-package.el ends here
